@@ -7,3 +7,6 @@ class LinkError(CompileError): pass
 class ConfigurationError(SolidbyteException): pass
 class AccountError(SolidbyteException): pass
 class ValidationError(SolidbyteException): pass
+class WrongPassword(ValidationError): pass
+class ScriptError(SolidbyteException): pass
+class InvalidScriptError(ValidationError): pass
